@@ -1,6 +1,10 @@
-# $Id: reorder.R,v 1.1 2002/08/01 18:06:41 warnes Exp $
+# $Id: reorder.R,v 1.2 2003/03/03 17:24:21 warnes Exp $
 #
 # $Log: reorder.R,v $
+# Revision 1.2  2003/03/03 17:24:21  warnes
+#
+# - Added handling of factor level names in addition to numeric indexes.
+#
 # Revision 1.1  2002/08/01 18:06:41  warnes
 #
 # Added reorder() function to reorder the levels of a factor.
@@ -12,5 +16,8 @@
 reorder <- function( X, order )
   {
     if(!is.factor(X)) stop("reorder only handles factor variables")
-    factor( X, levels=levels(X)[order] )
+    if(is.numeric(order))
+      factor( X, levels=levels(X)[order] )
+    else
+      factor( X, levels=order )
   }
